# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdMenu(Component):
    """An AntdMenu component.


Keyword arguments:
- id (string; optional)
- className (string; optional)
- style (dict; optional)
- menu_tree_structure (list; optional)
- current_key (string; optional)
- default_selected_keys (list of strings; optional)
- mode (string; default 'inline')"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, menu_tree_structure=Component.UNDEFINED, current_key=Component.UNDEFINED, default_selected_keys=Component.UNDEFINED, mode=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'style', 'menu_tree_structure', 'current_key', 'default_selected_keys', 'mode']
        self._type = 'AntdMenu'
        self._namespace = 'feffery_antd_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'style', 'menu_tree_structure', 'current_key', 'default_selected_keys', 'mode']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(AntdMenu, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdInput(Component):
    """An AntdInput component.


Keyword arguments:
- children (a list of or a singular dash component, string or number; optional)
- id (string; optional)
- className (string; optional)
- style (dict; optional)
- addonBefore (string; default '')
- addonAfter (string; default '')
- defaultValue (string; default '')
- placeholder (string; optional)
- value (string; optional)
- n_commits (number; default 0)
- maxLength (number; optional)"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, addonBefore=Component.UNDEFINED, addonAfter=Component.UNDEFINED, defaultValue=Component.UNDEFINED, placeholder=Component.UNDEFINED, value=Component.UNDEFINED, n_commits=Component.UNDEFINED, maxLength=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'style', 'addonBefore', 'addonAfter', 'defaultValue', 'placeholder', 'value', 'n_commits', 'maxLength']
        self._type = 'AntdInput'
        self._namespace = 'feffery_antd_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'style', 'addonBefore', 'addonAfter', 'defaultValue', 'placeholder', 'value', 'n_commits', 'maxLength']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(AntdInput, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdTab(Component):
    """An AntdTab component.


Keyword arguments:
- children (a list of or a singular dash component, string or number; optional)
- id (string; optional)
- tab (string; optional)
- key (string; optional)
- disabled (string; optional)
- className (string; optional)
- style (dict; optional)"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, tab=Component.UNDEFINED, key=Component.UNDEFINED, disabled=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'tab', 'key', 'disabled', 'className', 'style']
        self._type = 'AntdTab'
        self._namespace = 'feffery_antd_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'tab', 'key', 'disabled', 'className', 'style']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(AntdTab, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdTree(Component):
    """An AntdTree component.


Keyword arguments:
- id (string; optional)
- className (string; optional)
- style (dict; optional)
- treeData (list; required)
- showIcon (boolean; default True)
- checkable (boolean; default False)
- defaultCheckedKeys (list; optional)
- defaultExpandAll (boolean; default False)
- defaultExpandedKeys (list; optional)
- defaultExpandParent (boolean; default False)
- defaultSelectedKeys (list; optional)
- multiple (boolean; default False)
- selectable (boolean; default True)
- showLine (a value equal to: PropTypes.bool, PropTypes.exact({ showLeafIcon: PropTypes.bool }); default { showLeafIcon: false })
- selectedKeys (list; optional)
- checkedKeys (list; optional)
- height (number; optional)"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, treeData=Component.REQUIRED, showIcon=Component.UNDEFINED, checkable=Component.UNDEFINED, defaultCheckedKeys=Component.UNDEFINED, defaultExpandAll=Component.UNDEFINED, defaultExpandedKeys=Component.UNDEFINED, defaultExpandParent=Component.UNDEFINED, defaultSelectedKeys=Component.UNDEFINED, multiple=Component.UNDEFINED, selectable=Component.UNDEFINED, showLine=Component.UNDEFINED, selectedKeys=Component.UNDEFINED, checkedKeys=Component.UNDEFINED, height=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'style', 'treeData', 'showIcon', 'checkable', 'defaultCheckedKeys', 'defaultExpandAll', 'defaultExpandedKeys', 'defaultExpandParent', 'defaultSelectedKeys', 'multiple', 'selectable', 'showLine', 'selectedKeys', 'checkedKeys', 'height']
        self._type = 'AntdTree'
        self._namespace = 'feffery_antd_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'style', 'treeData', 'showIcon', 'checkable', 'defaultCheckedKeys', 'defaultExpandAll', 'defaultExpandedKeys', 'defaultExpandParent', 'defaultSelectedKeys', 'multiple', 'selectable', 'showLine', 'selectedKeys', 'checkedKeys', 'height']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['treeData']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(AntdTree, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdDatePicker(Component):
    """An AntdDatePicker component.


Keyword arguments:

- id (string; optional)

- allowClear (boolean; default True)

- className (string; optional)

- defaultPickerValue (dict; optional)

    `defaultPickerValue` is a dict with keys:

    - format (string; optional)

    - value (string; optional)

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- picker (string; default 'date')

- placeholder (string; default '')

- selectedDate (string; optional)

- showTime (boolean; default False)

- style (dict; default {
    width: 220
})"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, picker=Component.UNDEFINED, selectedDate=Component.UNDEFINED, showTime=Component.UNDEFINED, allowClear=Component.UNDEFINED, defaultPickerValue=Component.UNDEFINED, placeholder=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'allowClear', 'className', 'defaultPickerValue', 'loading_state', 'picker', 'placeholder', 'selectedDate', 'showTime', 'style']
        self._type = 'AntdDatePicker'
        self._namespace = 'feffery_antd_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'allowClear', 'className', 'defaultPickerValue', 'loading_state', 'picker', 'placeholder', 'selectedDate', 'showTime', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(AntdDatePicker, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdButton(Component):
    """An AntdButton component.


Keyword arguments:
- children (a list of or a singular dash component, string or number; optional)
- id (string; optional)
- className (string; optional)
- style (dict; optional)
- type (string; default 'default')
- href (string; optional)
- target (string; optional)
- block (boolean; default False)
- danger (boolean; default False)
- disabled (boolean; default False)
- shape (string; optional)
- n_clicks (number; default 0)"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, type=Component.UNDEFINED, href=Component.UNDEFINED, target=Component.UNDEFINED, block=Component.UNDEFINED, danger=Component.UNDEFINED, disabled=Component.UNDEFINED, shape=Component.UNDEFINED, n_clicks=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'style', 'type', 'href', 'target', 'block', 'danger', 'disabled', 'shape', 'n_clicks']
        self._type = 'AntdButton'
        self._namespace = 'feffery_antd_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'style', 'type', 'href', 'target', 'block', 'danger', 'disabled', 'shape', 'n_clicks']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(AntdButton, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdTransfer(Component):
    """An AntdTransfer component.


Keyword arguments:
- children (a list of or a singular dash component, string or number; optional)
- id (string; optional)
- className (string; optional)
- style (dict; optional)
- targetKeys (list; optional)
- moveDirection (string; optional)
- moveKeys (list; optional)
- pagination (dict; default False): pagination has the following type: boolean | dict containing keys 'pageSize'.
Those keys have the following types:
  - pageSize (number; optional)
- operations (list; optional)
- showSearch (boolean; default False)
- showSelectAll (boolean; default True)
- titles (list; default ['Source', 'Target'])
- listStyle (dict; optional)"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, targetKeys=Component.UNDEFINED, moveDirection=Component.UNDEFINED, moveKeys=Component.UNDEFINED, pagination=Component.UNDEFINED, operations=Component.UNDEFINED, showSearch=Component.UNDEFINED, showSelectAll=Component.UNDEFINED, titles=Component.UNDEFINED, listStyle=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'style', 'targetKeys', 'moveDirection', 'moveKeys', 'pagination', 'operations', 'showSearch', 'showSelectAll', 'titles', 'listStyle']
        self._type = 'AntdTransfer'
        self._namespace = 'feffery_antd_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'style', 'targetKeys', 'moveDirection', 'moveKeys', 'pagination', 'operations', 'showSearch', 'showSelectAll', 'titles', 'listStyle']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(AntdTransfer, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdSelect(Component):
    """An AntdSelect component.


Keyword arguments:
- children (a list of or a singular dash component, string or number; optional)
- id (string; optional)
- className (string; optional)
- style (dict; optional)
- options (list; required)
- allowClear (boolean; default True)
- mode (string; default '')
- placeholder (string; optional)
- values (string | list of strings; optional)
- defaultValue (string | list of strings; optional)
- showSearch (boolean; default True)
- maxTagCount (number; default 5)
- listHeight (number; default 256)"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, options=Component.REQUIRED, allowClear=Component.UNDEFINED, mode=Component.UNDEFINED, placeholder=Component.UNDEFINED, values=Component.UNDEFINED, defaultValue=Component.UNDEFINED, showSearch=Component.UNDEFINED, maxTagCount=Component.UNDEFINED, listHeight=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'style', 'options', 'allowClear', 'mode', 'placeholder', 'values', 'defaultValue', 'showSearch', 'maxTagCount', 'listHeight']
        self._type = 'AntdSelect'
        self._namespace = 'feffery_antd_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'style', 'options', 'allowClear', 'mode', 'placeholder', 'values', 'defaultValue', 'showSearch', 'maxTagCount', 'listHeight']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['options']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(AntdSelect, self).__init__(children=children, **args)
